InspectorData class
Holds all debug information shown by DevOverlay.
Constructors
- InspectorData({required String route, required double screenWidth, required double screenHeight, required Brightness brightness, required String appVersion, required String buildNumber, required String deviceName, required String osVersion})
-
Creates an InspectorData instance.
const
Properties
- appVersion → String
-
App version string e.g.
1.0.0.final - brightness → Brightness
-
Current theme brightness.
final
- buildNumber → String
-
App build number e.g.
7.final - deviceName → String
-
Device model name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- osVersion → String
-
OS name and version.
final
- route → String
-
Current route name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenHeight → double
-
Screen height in logical pixels.
final
- screenWidth → double
-
Screen width in logical pixels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
loadStaticInfo(
) → Future< Map< String, String> > - Loads device and app info asynchronously.